@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2022 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -17,58 +17,61 @@
 # along with Auto-Multiple-Choice.  If not, see
 # <http://www.gnu.org/licenses/>.
 
+use warnings;
+use 5.012;
+
 package AMC::Export::register;
 
 sub new {
     my $class = shift;
-    my $self={};
-    bless ($self, $class);
+    my $self  = {};
+    bless( $self, $class );
     return $self;
 }
 
 sub name {
-  return("empty");
+    return ("empty");
 }
 
 sub extension {
-  return('.xxx');
+    return ('.xxx');
 }
 
 sub type {
-  my ($self)=@_;
-  my $ext=$self->extension();
-  $ext =~ s/^.*\.//;
-  return($ext);
+    my ($self) = @_;
+    my $ext = $self->extension();
+    $ext =~ s/^.*\.//;
+    return ($ext);
 }
 
 sub options_from_config {
-  my ($self,$config)=@_;
-  return();
+    my ( $self, $config ) = @_;
+    return ();
 }
 
 sub needs_catalog {
-  my ($self,$config)=@_;
-  return(0);
+    my ( $self, $config ) = @_;
+    return (0);
 }
 
 sub options_default {
-  return();
+    return ();
 }
 
 sub needs_module {
-  return();
+    return ();
 }
 
 sub build_config_gui {
-  my ($self,$w,$prefs)=@_;
+    my ( $self, $main_ui ) = @_;
 }
 
 sub hide {
-  return('standard_export_options'=>0);
+    return ( standard_export_options => 0 );
 }
 
 sub weight {
-  return(1);
+    return (1);
 }
 
 1;
